@@ -1,5 +1,4 @@
 from functools import wraps
-from collections import OrderedDict
 from flask import request, Response
 from flask import abort as original_flask_abort
 from flask.views import MethodView
@@ -7,6 +6,12 @@ from werkzeug.exceptions import HTTPException
 from flask.ext.restful.utils import unauthorized, error_data, unpack
 from flask.ext.restful.representations.json import output_json
 
+try:
+    #noinspection PyUnresolvedReferences
+    from collections import OrderedDict
+except ImportError:
+    from utils.ordereddict import OrderedDict
+
 __all__ = ('Api', 'Resource', 'marshal', 'marshal_with', 'abort')
 
 
@@ -76,8 +81,7 @@ class Api(object):
         :type resource: Resource
         :param urls: one or more url routes to match for the resource, standard
                      flask routing rules apply.  Any url variables will be
-                     passed to the resource
-        method as args.
+                     passed to the resource method as args.
         :type urls: str
 
         :param endpoint: endpoint name (defaults to Resource.__name__.lower()
